//+------------------------------------------------------------------+
//|                                                  PanelDialog.mqh |
//|                   Copyright 2009-2017, MetaQuotes Software Corp. |
//|                                              http://www.mql5.com |
//+------------------------------------------------------------------+
#include <Controls\Dialog.mqh>
#include <Arrays\ArrayObj.mqh> 
#include <Controls\Label.mqh>
#property version   "1.001"
//+------------------------------------------------------------------+
//| defines                                                          |
//+------------------------------------------------------------------+
//--- indents and gaps
#define INDENT_LEFT                         (11)      // indent from left (with allowance for border width)
#define INDENT_TOP                          (11)      // indent from top (with allowance for border width)
#define INDENT_RIGHT                        (11)      // indent from right (with allowance for border width)
#define INDENT_BOTTOM                       (11)      // indent from bottom (with allowance for border width)
#define CONTROLS_GAP_X                      (10)      // gap by X coordinate
#define CONTROLS_GAP_Y                      (10)      // gap by Y coordinate
//--- for buttons
#define BUTTON_WIDTH                        (100)     // size by X coordinate
#define BUTTON_HEIGHT                       (20)      // size by Y coordinate
//--- for the indication area
#define EDIT_HEIGHT                         (20)      // size by Y coordinate
//+------------------------------------------------------------------+
//| Class CPanelDialog                                               |
//| Usage: main dialog of the SimplePanel application                |
//+------------------------------------------------------------------+
class CPanelDialog : public CAppDialog
  {
private:

public:
                     CPanelDialog(void);
                    ~CPanelDialog(void);
   //--- initialization
   virtual bool      Init(const string &symbols[]);
   //--- create
   virtual bool      Create(const long chart,const string name,const int subwin,const int x1,const int y1,const int x2,const int y2);
   //--- chart event handler
   //virtual bool      OnEvent(const int id,const long &lparam,const double &dparam,const string &sparam);

protected:
   //--- create dependent controls 
   bool              CreateLabels(void);

   //--- internal event handlers
   virtual bool      OnResize(void);
   //--- handlers of the dependent controls events

private:
   string            m_arr_symbols[];  // when changing a symbol or changing a timeframe, this array is recreated//--- create array 
   CArrayObj        *m_arr_obj;

  };
//+------------------------------------------------------------------+
//| Event Handling                                                   |
//+------------------------------------------------------------------+
//EVENT_MAP_BEGIN(CPanelDialog)
//   ON_EVENT(ON_CLICK,m_button1,OnClickButton1)
//   ON_EVENT(ON_CLICK,m_button2,OnClickButton2)
//   ON_EVENT(ON_CLICK,m_button3,OnClickButton3)
//   ON_EVENT(ON_CHANGE,m_radio_group,OnChangeRadioGroup)
//   ON_EVENT(ON_CHANGE,m_check_group,OnChangeCheckGroup)
//   ON_EVENT(ON_CHANGE,m_list_view,OnChangeListView)
//EVENT_MAP_END(CAppDialog)
//+------------------------------------------------------------------+
//| Constructor                                                      |
//+------------------------------------------------------------------+
CPanelDialog::CPanelDialog(void)
  {
//Print(__FUNCTION__,": Before resize ArraySize(m_arr_symbols)=",ArraySize(m_arr_symbols));
//ArrayResize(m_arr_symbols,3);
//m_arr_symbols[0]="FIrst";
//Print(__FUNCTION__,": After resize ArraySize(m_arr_symbols)=",ArraySize(m_arr_symbols));
  }
//+------------------------------------------------------------------+
//| Destructor                                                       |
//+------------------------------------------------------------------+
CPanelDialog::~CPanelDialog(void)
  {
   delete(m_arr_obj);
  }
//+------------------------------------------------------------------+
//| Create                                                           |
//+------------------------------------------------------------------+
bool CPanelDialog::Create(const long chart,const string name,const int subwin,const int x1,const int y1,const int x2,const int y2)
  {
   int total=m_arr_obj.Total();
   int Y2=31+INDENT_TOP+CONTROLS_GAP_Y+total*20+(total-1)*CONTROLS_GAP_Y;
   if(!CAppDialog::Create(chart,name,subwin,x1,y1,x2,y1+Y2))
      return(false);
//--- create dependent controls 
   if(!CreateLabels())
      return(false);
//--- succeed
   return(true);
  }
//+------------------------------------------------------------------+
//| Initialization                                                   |
//+------------------------------------------------------------------+
bool CPanelDialog::Init(const string &symbols[])
  {
   ArrayCopy(m_arr_symbols,symbols,0,0,WHOLE_ARRAY);
   Print(__FUNCTION__,": ");
   if(ArraySize(m_arr_symbols)>0)
     {
      for(int i=0;i<ArraySize(m_arr_symbols);i++)
        {
         PrintFormat("m_arr_symbols[%d]=\"%s\"",i,m_arr_symbols[i]);
        }
     }
//--- create objects array 
   m_arr_obj=new CArrayObj;
   if(m_arr_obj==NULL)
     {
      printf("Objects array create error");
      return(false);
     }
//--- create subarrays 
   for(int i=0;i<ArraySize(m_arr_symbols);i++)
     {
      CLabel *label=new CLabel;
      if(label==NULL)
        {
         delete m_arr_obj;
         printf("Object label create error");
         return(false);
        }
      //--- add oblect label
      m_arr_obj.Add(label);
     }
//---
   return(true);
  }
//+------------------------------------------------------------------+
//| Create Labels                                                    |
//+------------------------------------------------------------------+
bool CPanelDialog::CreateLabels(void)
  {
   for(int i=0;i<m_arr_obj.Total();i++)
     {
      CLabel *label=m_arr_obj.At(i);
      if(label==NULL)
        {
         delete m_arr_obj;
         printf("CreateLabels: Object label create error");
         return(false);
        }
      //--- coordinates 
      int x1=INDENT_RIGHT;
      int y1=INDENT_TOP+20*i+CONTROLS_GAP_Y*i;
      int x2=x1+100;
      int y2=y1+20;
      //--- create 
      if(!label.Create(m_chart_id,m_name+m_arr_symbols[i],m_subwin,x1,y1,x2,y2))
         return(false);
      if(!label.Text(m_arr_symbols[i]))
         return(false);
      if(!Add(label))
         return(false);
     }
//--- succeed 
   return(true);
  }
//+------------------------------------------------------------------+
//| Handler of resizing                                              |
//+------------------------------------------------------------------+
bool CPanelDialog::OnResize(void)
  {
////--- call method of parent class
//   if(!CAppDialog::OnResize()) return(false);
////--- coordinates
//   int x=ClientAreaLeft()+INDENT_LEFT;
//   int y=m_radio_group.Top();
//   int sx=(ClientAreaWidth()-(INDENT_LEFT+INDENT_RIGHT+BUTTON_WIDTH))/3-CONTROLS_GAP_X;
////--- move and resize the "RadioGroup" element
//   m_radio_group.Move(x,y);
//   m_radio_group.Width(sx);
////--- move and resize the "CheckGroup" element
//   x=ClientAreaLeft()+INDENT_LEFT+sx+CONTROLS_GAP_X;
//   m_check_group.Move(x,y);
//   m_check_group.Width(sx);
////--- move and resize the "ListView" element
//   x=ClientAreaLeft()+ClientAreaWidth()-(sx+INDENT_RIGHT+BUTTON_WIDTH+CONTROLS_GAP_X);
//   m_list_view.Move(x,y);
//   m_list_view.Width(sx);
//--- succeed
   return(true);
  }
//+------------------------------------------------------------------+
